@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -32,6 +32,7 @@
  * Types
  */
 
+#include "ale_fixed.h"
 #include "ale_pos.h"
 #include "ale_real.h"
 
@@ -39,11 +40,11 @@
  * Version Information
  */
 
-char *package_name = PACKAGE_NAME;
+const char *package_name = PACKAGE_NAME;
 
-char *short_version = VERSION;
+const char *short_version = VERSION;
 
-char *version = PACKAGE_NAME " Version:      " VERSION "\n"
+const char *version = PACKAGE_NAME " Version:      " VERSION "\n"
 #ifdef USE_MAGICK
 		"File handler:     ImageMagick\n"
 #else
