@@ -5,7 +5,7 @@
 
     The Anti-Lamenessing Engine is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     The Anti-Lamenessing Engine is distributed in the hope that it will be useful,
@@ -26,7 +26,7 @@
 
 int image_rw::ppm_type = 0;
 
-unsigned int image_rw::num_bits = 8;
+unsigned int image_rw::num_bits = 16;
 unsigned int image_rw::mcv = 255;
 
 unsigned int image_rw::file_count = 0;
@@ -36,7 +36,10 @@ const image **image_rw::images = NULL;
 int *image_rw::files_open;
 
 int image_rw::latest_close_num = -1;
-const image *image_rw::latest_close = NULL;
+
+double image_rw::cache_size = 0;
+double image_rw::cache_size_max = 256;
+unsigned int image_rw::cache_count = 0;
 
 double image_rw::nn_defined_radius = 0;
 
