@@ -57,7 +57,7 @@
  */
 
 extern "C" {
-#include "string.h"
+#include "string_.h"
 }
 
 /*
@@ -371,8 +371,6 @@ class input {
 			snprintf(desired_string, length, "%u %s", arg, name + strlen("0 "));
 
 			environment_map.erase(desired_string);
-
-			free(desired_string);
 		}
 
 		const char *get_string_arg(const char *name, unsigned int arg) {
@@ -1324,7 +1322,7 @@ public:
 				exit(1);
 			}
 
-			d2::image *i = new d2::image_ale_real((int)h, (int)w, 3);
+			d2::image *i = d2::new_image_ale_real((int)h, (int)w, 3);
 			d2::transformation t = d2::transformation::gpt_identity(i, 1);
 			d2::point q[4] = {
 				d2::point(tly, tlx),
@@ -2104,6 +2102,11 @@ public:
 
 				d2::image_rw::set_cache(cache);
 
+			} else if (!strcmp(option_name, "resident")) {
+				double resident = env->get_double_arg(i->first, 1);
+
+				d2::image::set_resident(resident);
+
 			} else if (!strcmp(option_name, "bayer")) {
 
 				/*
@@ -2299,6 +2302,8 @@ public:
 					d3::cpf::set_cpp_lower(perturb_lower);
 			} else if (!strcmp(option_name, "hf-enhance")) {
 				unsupported::discontinued("--hf-enhance=<x>");
+			} else if (!strcmp(option_name, "multi")) {
+				d2::trans_multi::set_multi(env->get_string_arg(i->first, 1));
 			} else if (!strcmp(option_name, "gs")) {
 				d2::align::gs(env->get_string_arg(i->first, 1));
 			} else if (!strcmp(option_name, "rot-upper")) {
@@ -2307,8 +2312,10 @@ public:
 				d2::align::set_bda_mult(env->get_double_arg(i->first, 1));
 			} else if (!strcmp(option_name, "bda-rate")) {
 				d2::align::set_bda_rate(env->get_double_arg(i->first, 1));
-			} else if (!strcmp(option_name, "lod-max")) {
-				d2::align::set_lod_max((int) floor(env->get_double_arg(i->first, 1)));
+			} else if (!strcmp(option_name, "lod-preferred")) {
+				d2::align::set_lod_preferred((int) floor(env->get_double_arg(i->first, 1)));
+			} else if (!strcmp(option_name, "min-dimension")) {
+				d2::align::set_min_dimension((int) ceil(env->get_double_arg(i->first, 1)));
 			} else if (!strcmp(option_name, "cpf-load")) {
 				d3::cpf::init_loadfile(env->get_string_arg(i->first, 1));
 #if 0
@@ -2712,7 +2719,11 @@ public:
 				if (!strcmp(option_name, "mc")) {
 					d2::align::mc(env->get_double_arg(i->first, 1));
 				} else if (!strcmp(option_name, "md")) {
-					d2::align::ma_decomp(env->get_int_arg(i->first, 1));
+					d2::trans_multi::set_md(env->get_double_arg(i->first, 1));
+				} else if (!strcmp(option_name, "ma-cert")) {
+					d2::align::set_ma_cert(env->get_double_arg(i->first, 1));
+				} else if (!strcmp(option_name, "mi")) {
+					d2::trans_multi::set_mi(env->get_double_arg(i->first, 1));
 				} else if (!strcmp(option_name, "gs-mo")) {
 					const char *option = env->get_string_arg(i->first, 1);
 					double gs_mo;
@@ -2846,14 +2857,24 @@ public:
 		 * XXX: note that the Irani-Peleg renderer currently
 		 * returns zero for ochain[0]->sync(), since it writes
 		 * output internally when inc != 0.
+		 *
+		 * XXX: Leave ochain[0] last, since this may allow disposal of
+		 * rendering structures not required by the Irani-Peleg
+		 * renderer.
 		 */
 
-		for (int opt = 0; opt < oc_count; opt++) 
+		for (int opt = 1; opt < oc_count; opt++) 
 		if  ((ochain[opt]->sync() || !inc) && !psf_match) {
 			ui::get()->writing_output(opt);
 			d2::image_rw::write_image(ochain_names[opt], ochain[opt]->get_image());
 		}
 
+		if (oc_count > 0)
+		if ((ochain[0]->sync() || !inc) && !psf_match) {
+			ui::get()->writing_output(0);
+			d2::image_rw::write_image(ochain_names[0], ochain[0]->get_image());
+		}
+
 		/*
 		 * Output a summary match statistic.
 		 */
