@@ -23,6 +23,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <stdarg.h>
 #include <assert.h>
 #include "../ale_pos.h"
@@ -43,6 +44,8 @@
 namespace d2 {
 	struct trans_multi;
 	typedef trans_multi transformation;
+	struct trans_abstract;
+	struct trans_single;
 }
 
 class ale_timer_t {
@@ -136,7 +139,7 @@ protected:
 			LOAD_FILE, EXPOSURE_PASS_1,
 			LODCLUSTER_CREATE, PREMATCH, ALIGN, GLOBAL_ALIGN, POSTMATCH,
 			EXPOSURE_PASS_2, RENDERA, RENDERD, RENDERO, WRITED,
-			WRITEO, FRAME_DONE, SET_DONE, 
+			WRITEO, FRAME_DONE, SET_DONE, MULTI,
 			
 			/*
 			 * Irani-Peleg rendering.
@@ -158,6 +161,7 @@ protected:
 		int onum;
 		int steps;
 		int steps_completed;
+		int step_type;
 		double exp_multiplier[3];
 		double perturb_size;
 		double align_lod;
@@ -314,8 +318,9 @@ public:
 		exp_multiplier(mult[0], mult[1], mult[2]);
 	}
 
-	virtual void set_steps(int count) {
+	virtual void set_steps(int count, int type = 0) {
 		status.steps = count;
+		status.step_type = type;
 	}
 
 	virtual void set_steps_completed(int count) {
@@ -327,7 +332,8 @@ public:
 		update();
 	}
 
-	virtual void set_offset(d2::transformation offset);
+	virtual void set_offset(d2::trans_single offset);
+	virtual void set_offset(d2::trans_multi offset);
 
 	virtual void gs_mo(ale_pos gs_mo) {
 	}
@@ -382,6 +388,11 @@ public:
 		update();
 	}
 
+	virtual void multi() {
+		status.code = status.MULTI;
+		update();
+	}
+
 	virtual void following() {
 	}
 
@@ -570,13 +581,28 @@ public:
 		update();
 	}
 
+	virtual void alignment_degree_complete(int degree) {
+		if (status.step_type == 1) {
+			status.steps_completed++;
+			printf("*");
+		}
+	}
+
 	virtual void alignment_perturbation_level(ale_pos perturb, ale_pos lod) {
 		perturb_timers[status.perturb_size].stop();
 		perturb_timers[perturb].start();
 		status.perturb_size = perturb;
 		status.align_lod = lod;
-		status.steps_completed++;
-		printf(".");
+		if (status.step_type == 0) {
+			status.steps_completed++;
+			printf(".");
+		}
+	}
+
+	virtual void alignment_dims(unsigned int hr, unsigned int wr, unsigned int hi, unsigned int wi) {
+	}
+
+	virtual void start_multi_alignment_element(d2::trans_multi &tm) {
 	}
 
 	virtual void alignment_match_ok() {
